@@ -6,15 +6,15 @@ exeout=`readlink -n -f -s ./`
 
 gcmpcroot=$exeout/gcmpcl
      pushd $gcmpcroot
-lazbuild --lazarusdir=$lazdir gcmp.lpr
-fpc -CX -XX -O4 -Cg -O4 acmp.pas
+lazbuild --lazarusdir=$lazdir --opt="-Cg -k-pie -k-znow" gcmp.lpi
+fpc -B -k-pie -k-znow -CfSSE64 -CX -XX -O3 -Mobjfpc -Cg acmp.pas
 mv acmp gcmp ../
 make clean
      popd
 
 fpwmroot=$exeout/fpwm-code
      pushd $fpwmroot
-lazbuild --lazarusdir=$lazdir fpwm.lpi
+lazbuild --lazarusdir=$lazdir --opt="-Cg -k-pie -k-znow" fpwm.lpi
 mv fpwm ../
      popd
 
