@@ -1,12 +1,11 @@
 #! /bin/bash
 
-# exit
-
 # User must be member of "src" group
 
 mseroot=./mseide-msegui
 #mseurl=https://github.com/mse-org/mseide-msegui
-mseurl=https://codeberg.org/fredvs/mseide-msegui
+#mseurl=https://codeberg.org/fredvs/mseide-msegui
+mseurl=https://codeberg.org/mse-org/mseide-msegui
 
 git clone $mseurl $mseroot
 
